import re


def judge(oscn_html):
    judge_re = r'Judge:\s*([\w\s\,]*)'
    find_judge = re.compile(judge_re, re.M)
    judge_search = find_judge.search(oscn_html)
    if judge_search.group:
        return judge_search.group(1)
    else:
        return None

setattr(judge,'target',['Case'])



from bs4 import BeautifulSoup
from ._helpers import text_values, add_properties

class DocketEvent(object):
    def __init__(self):
        pass


def docket(oscn_html):
    events = []
    soup = BeautifulSoup(oscn_html, 'html.parser')
    docket_table = soup.find('table', 'docketlist')
    thead = docket_table.find('thead').find_all('th')
    rows = docket_table.find('tbody').find_all('tr')
    headings = text_values(thead)

    for row in rows:
        cells=row.find_all('td')
        values = text_values(cells)
        event = DocketEvent()
        add_properties(event, headings, values)
        events.append(event)

        # clean up blank dates
        current_date = events[0].Date
        for e in events:
            if e.Date:
                current_date = e.Date
            else:
                e.Date = current_date

    return events

setattr(docket,'target',['Case'])



from bs4 import BeautifulSoup

from ._helpers import clean_string

def parties(oscn_html):
    parties_list = []
    names = []
    soup = BeautifulSoup(oscn_html, 'html.parser')
    start = soup.find('h2', 'section party')
    party_p = start.find_next_sibling('p')
    party_links = party_p.find_all('a')

    for link in party_links:
        names.append(clean_string(link.text))
        party_p.a.extract()

    party_type = party_p.text.split(',')
    party_type.pop(0)

    types = [clean_string(r) for r in party_type]

    Party = lambda name,type: {'name': name, 'type': type}

    result = map(Party, names, types)

    return [r for r in result]

# add this attribute to allow it to be added to request objects
setattr(parties,'target',['Case'])



from unicodedata import normalize

def clean_string(some_string):
    # removes escape chars and excess spaces
    normal_str = normalize('NFKD',some_string)
    return normal_str.strip()
    
def text_values(ResultSet):
    text_list =[]
    for el in ResultSet:
        text_list.append(clean_string(el.text))
    return text_list

def add_properties(obj, names, values):
    for idx, value in enumerate(values):
        setattr(obj, names[idx], value)



import re

def filed(oscn_html):
    pattern = r'Filed:\s*([\/\d]*)'
    find = re.compile(pattern, re.M)
    search = find.search(oscn_html)
    if search.group:
        return search.group(1)
    else:
        return None

setattr(filed,'target',['Case'])


def closed(oscn_html):
    pattern = r'Closed:\s*([\/\d]*)'
    find = re.compile(pattern, re.M)
    search = find.search(oscn_html)
    try:
        if search.group:
            return search.group(1)

    except AttributeError:
        return None

setattr(closed,'target',['Case'])
